@@ -137,8 +137,17 @@ def pstats2entries(data):
 def is_installed(prog):
     """Return whether or not a given executable is installed on the machine."""
     devnull = open(os.devnull, 'w')
-    retcode = subprocess.call(['which', prog], stdout=devnull)
+    
+    try:
+        if os.name == 'nt':
+            retcode = subprocess.call(['where', prog], stdout=devnull)
+        else:
+            retcode = subprocess.call(['which', prog], stdout=devnull)
+    except FileNotFoundError:
+        retcode = 1
+        
     devnull.close()
+        
     return retcode == 0
 
 
